Module: PoolParty::Remote::RemoterBaseMethods
- Defined in:
- lib/poolparty/net/remoter_base.rb
Overview
This class is the base class for all remote types Everything remoting-wise is derived from this class
Instance Method Summary collapse
-
#describe_instance(id = nil) ⇒ Object
Describe an instance's status.
-
#describe_instances ⇒ Object
Get instances The instances must have a status associated with them on the hash.
-
#launch_new_instance! ⇒ Object
Required methods The next methods are required on all RemoteInstance types If your RemoteInstance type does not overwrite the following methods An exception will be raised and poolparty will explode into tiny little pieces.
-
#terminate_instance!(id = nil) ⇒ Object
Terminate an instance by id.
Instance Method Details
#describe_instance(id = nil) ⇒ Object
Describe an instance's status
31 32 33 |
# File 'lib/poolparty/net/remoter_base.rb', line 31 def describe_instance(id=nil) raise RemoteException.new(:method_not_defined, "describe_instance") end |
#describe_instances ⇒ Object
Get instances The instances must have a status associated with them on the hash
36 37 38 |
# File 'lib/poolparty/net/remoter_base.rb', line 36 def describe_instances raise RemoteException.new(:method_not_defined, "describe_instances") end |
#launch_new_instance! ⇒ Object
Required methods The next methods are required on all RemoteInstance types If your RemoteInstance type does not overwrite the following methods An exception will be raised and poolparty will explode into tiny little pieces. Don't forget to overwrite these methods Launch a new instance
23 24 25 |
# File 'lib/poolparty/net/remoter_base.rb', line 23 def launch_new_instance! raise RemoteException.new(:method_not_defined, "launch_new_instance!") end |
#terminate_instance!(id = nil) ⇒ Object
Terminate an instance by id
27 28 29 |
# File 'lib/poolparty/net/remoter_base.rb', line 27 def terminate_instance!(id=nil) raise RemoteException.new(:method_not_defined, "terminate_instance!") end |